pub(crate) struct PositioningFragment {
pub base: BaseFragment,
pub children: Vec<Fragment>,
scrollable_overflow: AtomicRefCell<Option<PhysicalRect<Au>>>,
pub cumulative_containing_block_rect: AtomicRefCell<PhysicalRect<Au>>,
}Expand description
Can contain child fragments with relative coordinates, but does not contribute to painting
itself. PositioningFragments may be completely anonymous, or just non-painting Fragments
generated by boxes.
Fields
base: BaseFragmentchildren: Vec<Fragment>scrollable_overflow: AtomicRefCell<Option<PhysicalRect<Au>>>The scrollable overflow of this anonymous fragment’s children.
cumulative_containing_block_rect: AtomicRefCell<PhysicalRect<Au>>This PositioningFragment’s containing block rectangle in coordinates relative to
the initial containing block, but not taking into account any transforms.
Implementations
Sourceimpl PositioningFragment
impl PositioningFragment
fn build_stacking_context_tree( &self, stacking_context_tree: &mut StackingContextTree, containing_block: &ContainingBlock, containing_block_info: &ContainingBlockManager<'_, ContainingBlock>, stacking_context: &mut StackingContext, text_decorations: &Arc<Vec<FragmentTextDecoration>>, )
Sourceimpl PositioningFragment
impl PositioningFragment
pub fn new_anonymous( style: ServoArc<ComputedValues>, rect: PhysicalRect<Au>, children: Vec<Fragment>, ) -> Arc<Self>
pub fn new_empty( base_fragment_info: BaseFragmentInfo, rect: PhysicalRect<Au>, style: ServoArc<ComputedValues>, ) -> Arc<Self>
fn new_with_base_fragment_info( base_fragment_info: BaseFragmentInfo, style: ServoArc<ComputedValues>, rect: PhysicalRect<Au>, children: Vec<Fragment>, ) -> Arc<Self>
pub(crate) fn set_containing_block(&self, containing_block: &PhysicalRect<Au>)
pub fn offset_by_containing_block( &self, rect: &PhysicalRect<Au>, containing_block_computation: ContainingBlockCalculation<'_>, ) -> PhysicalRect<Au>
Sourcepub(crate) fn scrollable_overflow_for_parent(&self) -> PhysicalRect<Au>
pub(crate) fn scrollable_overflow_for_parent(&self) -> PhysicalRect<Au>
Get the scrollable overflow for this PositioningFragment relative to its
containing block, recalculating scrollable overflow when necessary, for instance
after a style change.
Sourcepub(crate) fn clear_scrollable_overflow(&self)
pub(crate) fn clear_scrollable_overflow(&self)
Clear the scrollable overflow on this PositioningFragment. This is called
during damage propagation when a fragment is preserved, itself or one of its
descendants has scrollable overflow damage.
fn calculate_scrollable_overflow(&self) -> PhysicalRect<Au>
pub fn print(&self, tree: &mut PrintTree)